S class

Constructors

S()

Properties

add → String
Add
no setter
camera → String
Camera
no setter
cancel → String
Cancel
no setter
close → String
Close
no setter
commit → String
Commit
no setter
confirm → String
Confirm
no setter
confirmDelete → String
Are you sure?
no setter
delete → String
Delete
no setter
edit → String
Edit
no setter
Gallery
no setter
hashCode → int
The hash code for this object.
no setterinherited
information → String
Information
no setter
operating → String
Operating
no setter
query → String
Filter
no setter
reset → String
Reset
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
save → String
Save
no setter
saved → String
Saved Successfully
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current → S
no setter

Static Methods

load(Locale locale) → Future<S>
maybeOf(BuildContext context) → S?
of(BuildContext context) → S

Constants

delegate → const AppLocalizationDelegate