CryProperties class

Constructors

CryProperties({required ApiProperties apiProperties, required LoggerProperties loggerProperties})
CryProperties.fromJson(String source)
factory
CryProperties.fromMap(Map<String, dynamic> map)
factory

Properties

apiProperties ↔ ApiProperties
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
loggerProperties ↔ LoggerProperties
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ApiProperties? apiProperties, LoggerProperties? loggerProperties}) → CryProperties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant CryProperties other) → bool
The equality operator.
override